// URL of the CSV file
const csvFileUrl =
  'https://gist.githubusercontent.com/Vishnupriyaeupuri/60279d9a4757682bdd28e1e83e86edbe/raw/702652dac8375312401432ec7615baab0eda23ec/year.csv';

// Load and process data from the CSV file
d3.csv(csvFileUrl)
  .then(function (dataset) {
    // Parse data: convert strings to appropriate data types
    dataset.forEach(function (dataPoint) {
      dataPoint.xValue = +dataPoint.Year; // Convert 'Year' to a number and store in 'xValue'
      dataPoint.yValue = +dataPoint.Value; // Convert 'Value' to a number and store in 'yValue'
    });

    // Chart dimensions setup
    const chartWidth = 800;
    const chartHeight = 400;
    const chartMargin = { top: 20, right: 20, bottom: 50, left: 50 };
    const chartInnerWidth = chartWidth - chartMargin.left - chartMargin.right;
    const chartInnerHeight = chartHeight - chartMargin.top - chartMargin.bottom;

    // Create the SVG container for the chart
    const svgContainer = d3
      .select('body')
      .append('svg')
      .attr('id', 'areachart')
      .attr('width', chartWidth)
      .attr('height', chartHeight);

    // Define scales for the axes
    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(dataset, (dataPoint) => dataPoint.xValue))
      .range([chartMargin.left, chartInnerWidth]);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(dataset, (dataPoint) => dataPoint.yValue)])
      .range([chartInnerHeight, chartMargin.top]);

    // Define the area generator for the chart
    const areaGenerator = d3
      .area()
      .x((dataPoint) => xScale(dataPoint.xValue))
      .y0(chartInnerHeight)
      .y1((dataPoint) => yScale(dataPoint.yValue));

    // Append the area shape to the SVG container
    svgContainer
      .append('path')
      .datum(dataset)
      .attr('fill', 'steelblue')
      .attr('d', areaGenerator);

    // Axes setup
    const xAxisGenerator = d3.axisBottom(xScale).tickFormat(d3.format('d'));
    const yAxisGenerator = d3.axisLeft(yScale);

    // Add the x-axis to the SVG container
    svgContainer
      .append('g')
      .attr('transform', translate(0, ${chartInnerHeight}))
      .call(xAxisGenerator)
      .append('text')
      .attr('x', chartInnerWidth / 2)
      .attr('y', chartMargin.bottom - 10)
      .attr('fill', 'black')
      .style('text-anchor', 'middle')
      .text('Year'); // x-axis label

    // Add the y-axis to the SVG container
    svgContainer
      .append('g')
      .attr('transform', translate(${chartMargin.left}, 0))
      .call(yAxisGenerator)
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -chartInnerHeight / 2)
      .attr('y', -chartMargin.left + 15)
      .attr('fill', 'black')
      .style('text-anchor', 'middle')
      .text('Value'); // y-axis label
  })
  .catch(function (error) {
    // Handle any errors during the data load
    console.error('Error loading the CSV file:', error);
  });